class ColabCounter:

    def __init__(self, seqproduto: int, date: str,
                 id_cliente: int, qtd_fatcupom: int):

        self.seqproduto = seqproduto
        self.date = date
        self.id_cliente = id_cliente
        self.qtd_fatcupom = qtd_fatcupom
