class ValidationDetail:

    def __init__(self, exec_date, industry_id, client_id, sale_date, validation_status):
        self.exec_date = exec_date
        self.industry_id = industry_id
        self.client_id = client_id
        self.sale_date = sale_date
        self.validation_status = validation_status

